C     Last change:  GK    9 Oct 1998    9:29 am
C**** RDMARFHP
c
      subroutine rdmarfhp( ierr )
c
c-----------------------------------------------------------------------
c
c    reads MARINE Fuel and HP packet
c    during execution of the commercial marine module of the NONROAD program.
c
c    Argument declaration.
c     Outputs:
c       ierr    I  error flag
c
c-----------------------------------------------------------------------
c    LOG:
c-----------------------------------------------------------------------
c
c      09/24/97  --gkohlbach-- cloned from rmexhman.for for marine model
c
c-----------------------------------------------------------------------
c    Include files:
c-----------------------------------------------------------------------
c
      include 'nonrdprm.inc'
      include 'nonrdio.inc'
      include 'nonrdefc.inc'
      include 'nonrdcmr.inc'
c
c-----------------------------------------------------------------------
c    Argument declarations:
c-----------------------------------------------------------------------
c
      integer*4     ierr
c
c-----------------------------------------------------------------------
c     Common block variables
c-----------------------------------------------------------------------
c   fhpscc  C   SCC                 cols  1-10
c   fhpcls  I   Size Class Group    cols 12-16
c   fhptyp  C   Class Type          cols 17-21
c   fhpahp  R   average horsepower  cols 22-28
c   fhpmxf  R   maximum fuel        cols 29-37
c   fhpman  R   %max maneuver       cols 38-41
c   fhpcru  R   %max cruise         cols 43-46
c   fhpslo  R   %max slow           cols 48-51
c   fhpful  R   %max full           cols 53-56
c
c
c-----------------------------------------------------------------------
c    External functions:
c-----------------------------------------------------------------------
c
c   strmin  I   returns the actual length of a string (min of 1)
c   fndchr  I   returns the index of string in array of strings
c   fndkey
c
      integer*4 strmin
c
c-----------------------------------------------------------------------
c    Local variables:
c-----------------------------------------------------------------------
c
      character*(4*MXSTR) line
      character*20        keywrd, keyin
      integer*4           irec, jerr
c
c-----------------------------------------------------------------------
c   Entry point:
c-----------------------------------------------------------------------
c
c   --- set error flag ---
c
      ierr = IFAIL
      irec = 0
c
c   --- call routine to find the /FUEL&HP/ packet ----
c
      keywrd = '/FUEL&HP/'
      call fndkey( jerr, IOREMS, keywrd )
      if( jerr .NE. ISUCES ) then
          ierr = ISUCES
          goto 9999
      endif
c
c   --- read a record as a character string --- 
c
  111 continue
      read(IOREMS,8002,ERR=7000,END=7000) line
      call mspinit()
c
c   --- check for the end keyword ---
c
      keyin = line(1:10)
      call lftjst( keyin )
      call low2up( keyin )
      if( keyin .EQ. KEYEND ) goto 222
c
c   --- parse the line
c    +-read fhpscc
c
      irec = irec + 1
      fhpscc(irec) = line(1:10)
      call lftjst( fhpscc(irec) )
      call low2up( fhpscc(irec) )
c
c    +-read fhpcls = Size Class Group
c
      read(line(11:17),'(I7)',ERR=7001) fhpcls(irec)
c
c    +-read fhptyp = Class Type
c
      fhptyp(irec) = line(17:21)
      call lftjst( fhptyp(irec) )
      call low2up( fhptyp(irec) )
c
c    +-read fhpahp = average horsepower
c
      read(line(22:28),'(F7.0)',ERR=7003) fhpahp(irec)
c
c    +-read fhpmxf = maximum fuel
c
      read(line(29:37),'(F7.0)',ERR=7004) fhpmxf(irec)
c
c    +-read fhpman = % maneuver
c
      read(line(38:41),'(F7.0)',ERR=7005) fhpman(irec)
c
c    +-read fhpcru = % cruise
c
      read(line(43:46),'(F7.0)',ERR=7006) fhpcru(irec)
c
c    +-read fhpslo = % slow
c
      read(line(48:51),'(F7.0)',ERR=7007) fhpslo(irec)
c
c    +-read fhpful = % full
c
      read(line(53:56),'(F7.0)',ERR=7008) fhpful(irec)
c
c   --- get the next record ---
c
      goto 111
c
c   --- finished reading file ---
c
  222 continue
      ierr = ISUCES
      nfhprc = irec
      goto 9999
c
c-----------------------------------------------------------------------
c   Error messages:
c-----------------------------------------------------------------------
c
 7000 continue
      write(IOWSTD,'(/,1X,3A)',ERR=9999) 'ERROR:  Reading from ',
     &           emfcfl, ', the marine emmission factors file.'
      write(IOWMSG,'(/,1X,3A)',ERR=9999) 'ERROR:  Reading from ',
     &           emfcfl, ', the marine emmission factors file.'
      goto 9999
c
 7001 continue
      write(IOWSTD,'(/,1X,2A,/,1X,1A)',ERR=9999)
     &   'Error reading fuel & hp size class from emis fact file. ',
     &                               'Line read: ',line(:strmin(line))
      write(IOWMSG,'(/,1X,2A,/,1X,1A)',ERR=9999)
     &   'Error reading fuel & hp size class from emis fact file. ',
     &                               'Line read: ',line(:strmin(line))
      goto 9999
c
 7003 continue
      write(IOWSTD,'(/,1X,2A,/,1X,1A)',ERR=9999)
     &         'Error reading avg hp from emission factors file ',
     &                               'Line read: ',line(:strmin(line))
      write(IOWMSG,'(/,1X,2A,/,1X,1A)',ERR=9999)
     &         'Error reading avg hp from emission factors file ',
     &                               'Line read: ',line(:strmin(line))
      goto 9999
c
 7004 continue
      write(IOWSTD,'(/,1X,2A,/,1X,1A)',ERR=9999)
     &         'Error reading max fuel from emission factors file ',
     &                               'Line read: ',line(:strmin(line))
      write(IOWMSG,'(/,1X,2A,/,1X,1A)',ERR=9999)
     &         'Error reading max fuel from emission factors file ',
     &                               'Line read: ',line(:strmin(line))
      goto 9999
c
 7005 continue
      write(IOWSTD,'(/,1X,2A,/,1X,1A)',ERR=9999)
     &         'Error reading % maneuver from emission factors file ',
     &                               'Line read: ',line(:strmin(line))
      write(IOWMSG,'(/,1X,2A,/,1X,1A)',ERR=9999)
     &         'Error reading % maneuver from emission factors file ',
     &                               'Line read: ',line(:strmin(line))
      goto 9999
c
 7006 continue
      write(IOWSTD,'(/,1X,2A,/,1X,1A)',ERR=9999)
     &         'Error reading % cruise from emission factors file ',
     &                               'Line read: ',line(:strmin(line))
      write(IOWMSG,'(/,1X,2A,/,1X,1A)',ERR=9999)
     &         'Error reading % cruise from emission factors file ',
     &                               'Line read: ',line(:strmin(line))
      goto 9999
c
 7007 continue
      write(IOWSTD,'(/,1X,2A,/,1X,1A)',ERR=9999)
     &         'Error reading % slow from emission factors file ',
     &                               'Line read: ',line(:strmin(line))
      write(IOWMSG,'(/,1X,2A,/,1X,1A)',ERR=9999)
     &         'Error reading % slow from emission factors file ',
     &                               'Line read: ',line(:strmin(line))
      goto 9999
c
 7008 continue
      write(IOWSTD,'(/,1X,2A,/,1X,1A)',ERR=9999)
     &         'Error reading % full from emission factors file ',
     &                               'Line read: ',line(:strmin(line))
      write(IOWMSG,'(/,1X,2A,/,1X,1A)',ERR=9999)
     &         'Error reading % full from emission factors file ',
     &                               'Line read: ',line(:strmin(line))
      goto 9999
c
c-----------------------------------------------------------------------
c   Format statements:
c-----------------------------------------------------------------------
c
 8000 format(A)
 8001 format(20(:,F10.0))
 8002 format(A132)
c
c-----------------------------------------------------------------------
c   Return point:
c-----------------------------------------------------------------------
c
 9999 continue
      return
      end
